@@ -1103,10 +1103,21 @@ setMethod("toTable", "Bimap",
     }
 )
 
-as.data.frame.Bimap <- function(x, row.names = NULL, optional = FALSE, ...)
-    as.data.frame(x, row.names=row.names, optional=optional, ...)
+as.data.frame.Bimap <- function(x, row.names=NULL, optional=FALSE, ...)
+{
+    if (!is.null(row.names))
+        warning(wmsg("the \"as.data.frame\" method for Bimap objects ",
+                     "ignores the 'row.names' argument"))
+    if (!identical(optional, FALSE))
+        warning(wmsg("the \"as.data.frame\" method for Bimap objects ",
+                     "ignores the 'optional' argument"))
+    if (length(list(...)) != 0L)
+        stop(wmsg("the \"as.data.frame\" method for Bimap objects ",
+                  "doesn't take any extra argument"))
+    toTable(x)
+}
 
-setMethod("as.data.frame", "Bimap", toTable)
+setMethod("as.data.frame", "Bimap", as.data.frame.Bimap)
 
 
 
@@ -1390,7 +1401,7 @@ setMethod("setInpBimapFilter", "InpAnnDbBimap",
 ## compatibility provided by getAnnMap() in the annotate package.
 
 
-## I need to check with Herve if my assumptions here are correct that I
+## I need to check with Hervé if my assumptions here are correct that I
 ## Don't want any NAs in @data OR in @Rkeys and @Lkeys???
 ## Maybe I don't want NAs in only one or the other?
 ## And maybe the answer is in how mappedLkeys and mappedRkeys work?
@@ -1411,7 +1422,7 @@ makeFlatBimapUsingSelect <- function(x, col){
 
 }
 
-## Herve says that I in fact want to have no NAs (and be unique) in the Rkey and Lkeys, and that I ALSO do not want ANY NAs in either column of @data.  So I have modified this function accordingly
+## Hervé says that I in fact want to have no NAs (and be unique) in the Rkey and Lkeys, and that I ALSO do not want ANY NAs in either column of @data.  So I have modified this function accordingly
 
 
 
